@@ -18,6 +18,12 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+//! This module implements "messy includes", or Wikidot native includes.
+//!
+//! It is an annoying but necessary hack that parses the psueodblock
+//! `[[include-messy]]` and directly replaces that part with the
+//! foreign page's wikitext.
+
 #[cfg(test)]
 mod test;
 
@@ -25,23 +31,26 @@ mod include_ref;
 mod includer;
 mod parse;
 
-pub use self::include_ref::{IncludeRef, IncludeVariables};
+pub use self::include_ref::IncludeRef;
 pub use self::includer::{DebugIncluder, FetchedPage, Includer, NullIncluder};
 
 use self::parse::parse_include_block;
 use crate::data::PageRef;
 use crate::log::prelude::*;
+use crate::tree::VariableMap;
 use regex::{Regex, RegexBuilder};
 
 lazy_static! {
     static ref INCLUDE_REGEX: Regex = {
-        RegexBuilder::new(r"^\[\[\s*include\s+")
+        RegexBuilder::new(r"^\[\[\s*include-messy\s+")
             .case_insensitive(true)
             .multi_line(true)
             .dot_matches_new_line(true)
             .build()
             .unwrap()
     };
+    static ref VARIABLE_REGEX: Regex =
+        Regex::new(r"\{\$(?P<name>[a-zA-Z0-9_\-]+)\}").unwrap();
 }
 
 pub fn include<'t, I, E, F>(
@@ -85,7 +94,7 @@ where
                 ranges.push(start..end);
                 includes.push(include);
             }
-            Err(_) => debug!(log, "Unable to parse include regex match"),
+            Err(_) => warn!(log, "Unable to parse include regex match"),
         }
     }
 
@@ -105,18 +114,18 @@ where
     let includes_iter = includes.into_iter();
     let fetched_iter = fetched_pages.into_iter();
 
+    let joined_iter = ranges_iter.zip(includes_iter).zip(fetched_iter).rev();
+
     // Borrowing from the original text and doing in-place insertions
     // will not work here. We are trying to both return the page names
     // (slices from the input string), and replace it with new content.
     let mut output = String::from(input);
     let mut pages = Vec::new();
 
-    for ((range, include), fetched) in
-        ranges_iter.zip(includes_iter).zip(fetched_iter).rev()
-    {
-        let (page_ref, _) = include.into();
+    for ((range, include), fetched) in joined_iter {
+        let (page_ref, variables) = include.into();
 
-        debug!(
+        info!(
             log,
             "Replacing range for included page";
             "span" => SpanWrap::from(&range),
@@ -130,20 +139,22 @@ where
         }
 
         // Get replaced content, or error message
-        let message;
         let replace_with = match fetched.content {
-            Some(ref content) => content,
-            None => {
-                message = includer.no_such_include(&page_ref)?;
-                &message
+            // Take fetched content, replace variables
+            Some(mut content) => {
+                replace_variables(content.to_mut(), &variables);
+                content
             }
+
+            // Include not found, return premade template
+            None => includer.no_such_include(&page_ref)?,
         };
 
         // Append page to final list
         pages.push(page_ref);
 
         // Perform the substitution
-        output.replace_range(range, replace_with);
+        output.replace_range(range, &replace_with);
     }
 
     // Since we iterate in reverse order, the pages are reversed.
@@ -152,3 +163,24 @@ where
     // Return
     Ok((output, pages))
 }
+
+fn replace_variables(content: &mut String, variables: &VariableMap) {
+    let mut matches = Vec::new();
+
+    // Find all variables
+    for capture in VARIABLE_REGEX.captures_iter(content) {
+        let mtch = capture.get(0).unwrap();
+        let name = &capture["name"];
+
+        if let Some(value) = variables.get(name) {
+            matches.push((value, mtch.range()));
+        }
+    }
+
+    // Replace the variables
+    // Iterates backwards so indices stay valid
+    matches.reverse();
+    for (value, range) in matches {
+        content.replace_range(range, value);
+    }
+}
