@@ -34,7 +34,7 @@ use strum_macros::IntoStaticStr;
 /// For instance, CSS styles are not present in the syntax tree
 /// like regular elements, and instead must be bubbled up
 /// to the top level.
-#[derive(Debug, Clone, PartialEq)]
+#[derive(Serialize, Deserialize, Debug, Clone, PartialEq, Eq)]
 pub enum ParseException<'t> {
     Warning(ParseWarning),
     Style(Cow<'t, str>),
@@ -47,7 +47,7 @@ pub enum ParseException<'t> {
 ///
 /// However, as outlined by the crate's philosophy, no parsing issue is fatal.
 /// Instead a fallback rules is applied and parsing continues.
-#[derive(Serialize, Deserialize, Debug, Clone, PartialEq)]
+#[derive(Serialize, Deserialize, Debug, Clone, PartialEq, Eq)]
 #[serde(rename_all = "kebab-case")]
 pub struct ParseWarning {
     token: Token,
@@ -131,9 +131,6 @@ pub enum ParseWarningKind {
     /// Attempting to process this rule failed because the end of input was reached.
     EndOfInput,
 
-    /// Temporary rule denoting that this syntactical construction isn't implemented yet.
-    NotImplemented,
-
     /// No rules match for these tokens, returning as plain text.
     NoRulesMatch,
 
@@ -158,6 +155,21 @@ pub enum ParseWarningKind {
     /// This list tries to nest too deeply.
     ListDepthExceeded,
 
+    /// This table has elements other than rows in it.
+    TableContainsNonRow,
+
+    /// This table row has elements other than cells in it.
+    TableRowContainsNonCell,
+
+    /// This table row appears outside of a table.
+    TableRowOutsideTable,
+
+    /// This table cell appears outside of a table row.
+    TableCellOutsideTable,
+
+    /// Footnotes are not permitted from inside footnotes.
+    FootnotesNested,
+
     /// This native blockquote tries to nest too deeply.
     BlockquoteDepthExceeded,
 
@@ -194,6 +206,12 @@ pub enum ParseWarningKind {
     /// This module does not specify a name.
     ModuleMissingName,
 
+    /// The given page to be included does not exist.
+    NoSuchPage,
+
+    /// The given variable was not found, and thus not substituted.
+    NoSuchVariable,
+
     /// The URL passed here was invalid.
     InvalidUrl,
 }
