@@ -27,10 +27,12 @@ mod collect;
 mod condition;
 mod consume;
 mod depth;
+mod element_condition;
 mod exception;
 mod outcome;
 mod paragraph;
 mod parser;
+mod parser_wrap;
 mod result;
 mod rule;
 mod string;
@@ -44,15 +46,18 @@ mod prelude {
         ParseWarningKind, Token,
     };
     pub use crate::text::FullText;
-    pub use crate::tree::{Element, Elements, ElementsIterator};
+    pub use crate::tree::{Element, Elements, OwnedElementsIterator};
 }
 
 use self::depth::{process_depths, DepthItem, DepthList};
+use self::element_condition::{ElementCondition, ElementConditionType};
 use self::paragraph::{gather_paragraphs, NO_CLOSE_CONDITION};
 use self::parser::Parser;
+use self::parser_wrap::ParserWrap;
 use self::rule::impls::RULE_PAGE;
 use self::string::parse_string;
-use self::strip::strip_newlines;
+use self::strip::{strip_newlines, strip_whitespace};
+use crate::data::PageInfo;
 use crate::log::prelude::*;
 use crate::next_index::{NextIndex, TableOfContentsIndex};
 use crate::tokenizer::Tokenization;
@@ -72,32 +77,27 @@ pub use self::token::{ExtractedToken, Token};
 /// This takes a list of `ExtractedToken` items produced by `tokenize()`.
 pub fn parse<'r, 't>(
     log: &Logger,
+    page_info: &'r PageInfo<'t>,
     tokenization: &'r Tokenization<'t>,
 ) -> ParseOutcome<SyntaxTree<'t>>
 where
     'r: 't,
 {
-    let mut parser = Parser::new(log, tokenization);
-
-    // Logging setup
-    let log = &log.new(slog_o!(
-        "filename" => slog_filename!(),
-        "lineno" => slog_lineno!(),
-        "function" => "parse",
-        "tokens-len" => tokenization.tokens().len(),
-    ));
-
-    // At the top level, we gather elements into paragraphs
-    info!(log, "Running parser on tokens");
-    let result = gather_paragraphs(log, &mut parser, RULE_PAGE, NO_CLOSE_CONDITION);
+    // Run parsing, get raw results
+    let UnstructuredParseResult {
+        result,
+        table_of_contents_depths,
+        footnotes,
+        has_footnote_block,
+    } = parse_internal(log, page_info, tokenization);
 
     // For producing table of contents indexes
     let mut incrementer = Incrementer(0);
 
-    debug!(log, "Finished paragraph gathering, matching on consumption");
+    info!(log, "Finished paragraph gathering, matching on consumption");
     match result {
         Ok(ParseSuccess {
-            item: elements,
+            item: mut elements,
             exceptions,
             ..
         }) => {
@@ -110,9 +110,10 @@ where
                 "styles-len" => styles.len(),
             );
 
-            // Extract supplementary tables from parser
-            let table_of_contents_depths = parser.remove_table_of_contents();
-            let footnotes = parser.remove_footnotes();
+            // process_depths() wants a "list type", so we map in a () for each.
+            let table_of_contents_depths = table_of_contents_depths
+                .into_iter()
+                .map(|(depth, contents)| (depth, (), contents));
 
             // Convert TOC depth lists
             let table_of_contents = process_depths((), table_of_contents_depths)
@@ -120,6 +121,17 @@ where
                 .map(|(_, items)| build_toc_list_element(&mut incrementer, items))
                 .collect::<Vec<_>>();
 
+            // Add a footnote block at the end,
+            // if the user doesn't have one already
+            if !has_footnote_block {
+                info!(log, "No footnote block in elements, appending one");
+
+                elements.push(Element::FootnoteBlock {
+                    title: None,
+                    hide: false,
+                });
+            }
+
             SyntaxTree::from_element_result(
                 elements,
                 warnings,
@@ -134,9 +146,10 @@ where
             // If this happens, then just return the input source as the output
             // and the warning.
 
-            warn!(
+            crit!(
                 log,
-                "Fatal error occurred at highest-level parsing: {:#?}", warning,
+                "Fatal error occurred at highest-level parsing: {:#?}",
+                warning,
             );
 
             let wikitext = tokenization.full_text().inner();
@@ -157,6 +170,44 @@ where
     }
 }
 
+/// Runs the parser, but returns the raw internal results prior to conversion.
+pub fn parse_internal<'r, 't>(
+    log: &Logger,
+    page_info: &'r PageInfo<'t>,
+    tokenization: &'r Tokenization<'t>,
+) -> UnstructuredParseResult<'r, 't>
+where
+    'r: 't,
+{
+    let mut parser = Parser::new(log, page_info, tokenization);
+
+    // Logging setup
+    let log = &log.new(slog_o!(
+        "filename" => slog_filename!(),
+        "lineno" => slog_lineno!(),
+        "function" => "parse",
+        "tokens-len" => tokenization.tokens().len(),
+    ));
+
+    // At the top level, we gather elements into paragraphs
+    info!(log, "Running parser on tokens");
+    let result = gather_paragraphs(log, &mut parser, RULE_PAGE, NO_CLOSE_CONDITION);
+
+    // Build and return
+    let table_of_contents_depths = parser.remove_table_of_contents();
+    let footnotes = parser.remove_footnotes();
+    let has_footnote_block = parser.has_footnote_block();
+
+    UnstructuredParseResult {
+        result,
+        table_of_contents_depths,
+        footnotes,
+        has_footnote_block,
+    }
+}
+
+// Helper functions
+
 fn extract_exceptions(
     exceptions: Vec<ParseException>,
 ) -> (Vec<ParseWarning>, Vec<Cow<str>>) {
@@ -178,7 +229,9 @@ fn build_toc_list_element(
     list: DepthList<(), String>,
 ) -> Element<'static> {
     let build_item = |item| match item {
-        DepthItem::List(_, list) => ListItem::SubList(build_toc_list_element(incr, list)),
+        DepthItem::List(_, list) => ListItem::SubList {
+            element: Box::new(build_toc_list_element(incr, list)),
+        },
         DepthItem::Item(name) => {
             let anchor = format!("#toc{}", incr.next());
             let link = Element::Link {
@@ -187,7 +240,10 @@ fn build_toc_list_element(
                 target: None,
             };
 
-            ListItem::Elements(vec![link])
+            ListItem::Elements {
+                elements: vec![link],
+                attributes: AttributeMap::new(),
+            }
         }
     };
 
@@ -201,6 +257,8 @@ fn build_toc_list_element(
     }
 }
 
+// Incrementer for TOC
+
 #[derive(Debug)]
 struct Incrementer(usize);
 
@@ -211,3 +269,25 @@ impl NextIndex<TableOfContentsIndex> for Incrementer {
         index
     }
 }
+
+// Parse internal result
+
+#[derive(Serialize, Deserialize, Debug, Clone)]
+pub struct UnstructuredParseResult<'r, 't> {
+    /// The returned result from parsing.
+    pub result: ParseResult<'r, 't, Vec<Element<'t>>>,
+
+    /// The "depths" list for table of content entries.
+    ///
+    /// Each value is a zero-indexed depth of how
+    pub table_of_contents_depths: Vec<(usize, String)>,
+
+    /// The list of footnotes.
+    ///
+    /// Each entry is a series of elements, in combination
+    /// they make the contents of one footnote.
+    pub footnotes: Vec<Vec<Element<'t>>>,
+
+    /// Whether a footnote block was placed during parsing.
+    pub has_footnote_block: bool,
+}
