@@ -26,7 +26,7 @@ use crate::data::PageInfo;
 use crate::log::prelude::*;
 use crate::render::text::TextRender;
 use crate::tokenizer::Tokenization;
-use crate::tree::HeadingLevel;
+use crate::tree::{AcceptsPartial, HeadingLevel};
 use std::cell::RefCell;
 use std::rc::Rc;
 use std::{mem, ptr};
@@ -38,6 +38,9 @@ pub struct Parser<'r, 't> {
     // Logger instance
     log: Logger,
 
+    // Page information
+    page_info: &'r PageInfo<'t>,
+
     // Parse state
     current: &'r ExtractedToken<'t>,
     remaining: &'r [ExtractedToken<'t>],
@@ -51,11 +54,11 @@ pub struct Parser<'r, 't> {
     //
     // Schema: Vec<(depth, _, name)>
     //
-    // Note: These two are in Rc<_> items so that the Parser
-    //       can be cloned. It is intended as a cheap pointer
-    //       object, with the true contents here preserved
-    //       across parser child instances.
-    table_of_contents: Rc<RefCell<Vec<(usize, (), String)>>>,
+    // Note: These three are in Rc<_> items so that the Parser
+    //       can be cloned. This struct is intended as a
+    //       cheap pointer object, with the true contents
+    //       here preserved across parser child instances.
+    table_of_contents: Rc<RefCell<Vec<(usize, String)>>>,
 
     // Footnotes
     //
@@ -63,7 +66,9 @@ pub struct Parser<'r, 't> {
     footnotes: Rc<RefCell<Vec<Vec<Element<'t>>>>>,
 
     // Flags
-    in_list: bool,
+    accepts_partial: AcceptsPartial,
+    in_footnote: bool, // Whether we're currently inside [[footnote]] ... [[/footnote]].
+    has_footnote_block: bool, // Whether a [[footnoteblock]] was created.
     start_of_line: bool,
 }
 
@@ -72,7 +77,11 @@ impl<'r, 't> Parser<'r, 't> {
     ///
     /// All other instances should be `.clone()` or `.clone_with_rule()`d from
     /// the main instance used during parsing.
-    pub(crate) fn new(log: &Logger, tokenization: &'r Tokenization<'t>) -> Self {
+    pub(crate) fn new(
+        log: &Logger,
+        page_info: &'r PageInfo<'t>,
+        tokenization: &'r Tokenization<'t>,
+    ) -> Self {
         let log = Logger::clone(log);
         let full_text = tokenization.full_text();
         let (current, remaining) = tokenization
@@ -80,19 +89,19 @@ impl<'r, 't> Parser<'r, 't> {
             .split_first()
             .expect("Parsed tokens list was empty (expected at least one element)");
 
-        let table_of_contents = make_shared_vec();
-        let footnotes = make_shared_vec();
-
         Parser {
             log,
+            page_info,
             current,
             remaining,
             full_text,
             rule: RULE_PAGE,
             depth: 0,
-            table_of_contents,
-            footnotes,
-            in_list: false,
+            table_of_contents: make_shared_vec(),
+            footnotes: make_shared_vec(),
+            accepts_partial: AcceptsPartial::None,
+            in_footnote: false,
+            has_footnote_block: false,
             start_of_line: true,
         }
     }
@@ -103,6 +112,11 @@ impl<'r, 't> Parser<'r, 't> {
         Logger::clone(&self.log)
     }
 
+    #[inline]
+    pub fn page_info(&self) -> &PageInfo<'t> {
+        self.page_info
+    }
+
     #[inline]
     pub fn full_text(&self) -> FullText<'t> {
         self.full_text
@@ -114,8 +128,18 @@ impl<'r, 't> Parser<'r, 't> {
     }
 
     #[inline]
-    pub fn in_list(&self) -> bool {
-        self.in_list
+    pub fn accepts_partial(&self) -> AcceptsPartial {
+        self.accepts_partial
+    }
+
+    #[inline]
+    pub fn in_footnote(&self) -> bool {
+        self.in_footnote
+    }
+
+    #[inline]
+    pub fn has_footnote_block(&self) -> bool {
+        self.has_footnote_block
     }
 
     #[inline]
@@ -155,8 +179,18 @@ impl<'r, 't> Parser<'r, 't> {
     }
 
     #[inline]
-    pub fn set_list_flag(&mut self, value: bool) {
-        self.in_list = value;
+    pub fn set_accepts_partial(&mut self, value: AcceptsPartial) {
+        self.accepts_partial = value;
+    }
+
+    #[inline]
+    pub fn set_footnote_flag(&mut self, value: bool) {
+        self.in_footnote = value;
+    }
+
+    #[inline]
+    pub fn set_footnote_block(&mut self) {
+        self.has_footnote_block = true;
     }
 
     // Table of Contents
@@ -165,35 +199,22 @@ impl<'r, 't> Parser<'r, 't> {
         heading: HeadingLevel,
         name_elements: &[Element],
     ) {
-        // TODO provide real PageInfo
-        let info = PageInfo {
-            page: cow!("table-of-contents"),
-            category: None,
-            site: cow!(""),
-            title: cow!("Table of Contents"),
-            alt_title: None,
-            rating: 0.0,
-            tags: vec![],
-            language: cow!("unknown"),
-        };
-
         // Headings are 1-indexed (e.g. H1), but depth lists are 0-indexed
         let level = usize::from(heading.value()) - 1;
 
         // Render name as text, so it lacks formatting
-        let name = TextRender.render_partial(&self.log, &info, name_elements);
+        let name = TextRender.render_partial(&self.log, self.page_info, name_elements);
 
-        self.table_of_contents.borrow_mut().push((level, (), name));
+        self.table_of_contents.borrow_mut().push((level, name));
     }
 
     #[cold]
-    pub fn remove_table_of_contents(&mut self) -> Vec<(usize, (), String)> {
+    pub fn remove_table_of_contents(&mut self) -> Vec<(usize, String)> {
         mem::take(&mut self.table_of_contents.borrow_mut())
     }
 
     // Footnotes
     pub fn push_footnote(&mut self, contents: Vec<Element<'t>>) {
-        // TODO
         self.footnotes.borrow_mut().push(contents);
     }
 
@@ -202,9 +223,22 @@ impl<'r, 't> Parser<'r, 't> {
         mem::take(&mut self.footnotes.borrow_mut())
     }
 
+    // Special for [[include]], appending a SyntaxTree
+    pub fn append_toc_and_footnotes(
+        &mut self,
+        table_of_contents: &mut Vec<(usize, String)>,
+        footnotes: &mut Vec<Vec<Element<'t>>>,
+    ) {
+        self.table_of_contents
+            .borrow_mut()
+            .append(table_of_contents);
+
+        self.footnotes.borrow_mut().append(footnotes);
+    }
+
     // State evaluation
     pub fn evaluate(&self, condition: ParseCondition) -> bool {
-        debug!(
+        info!(
             &self.log,
             "Evaluating parser condition";
             "current-token" => self.current.token,
@@ -216,7 +250,7 @@ impl<'r, 't> Parser<'r, 't> {
             ParseCondition::CurrentToken(token) => self.current.token == token,
             ParseCondition::TokenPair(current, next) => {
                 if self.current().token != current {
-                    trace!(
+                    debug!(
                         &self.log,
                         "Current token in pair doesn't match, failing";
                         "expected" => current,
@@ -229,7 +263,7 @@ impl<'r, 't> Parser<'r, 't> {
                 match self.look_ahead(0) {
                     Some(actual) => {
                         if actual.token != next {
-                            trace!(
+                            debug!(
                                 &self.log,
                                 "Second token in pair doesn't match, failing";
                                 "expected" => next,
@@ -240,7 +274,7 @@ impl<'r, 't> Parser<'r, 't> {
                         }
                     }
                     None => {
-                        trace!(
+                        debug!(
                             &self.log,
                             "Second token in pair doesn't exist, failing";
                             "expected" => next,
@@ -257,7 +291,7 @@ impl<'r, 't> Parser<'r, 't> {
 
     #[inline]
     pub fn evaluate_any(&self, conditions: &[ParseCondition]) -> bool {
-        trace!(
+        info!(
             &self.log,
             "Evaluating to see if any parser condition is true";
             "conditions-len" => conditions.len(),
@@ -271,7 +305,7 @@ impl<'r, 't> Parser<'r, 't> {
     where
         F: FnOnce(&mut Parser<'r, 't>) -> Result<bool, ParseWarning>,
     {
-        debug!(&self.log, "Evaluating closure for parser condition");
+        info!(&self.log, "Evaluating closure for parser condition");
 
         f(&mut self.clone()).unwrap_or(false)
     }
@@ -280,7 +314,7 @@ impl<'r, 't> Parser<'r, 't> {
     where
         F: FnOnce(&mut Parser<'r, 't>) -> Result<bool, ParseWarning>,
     {
-        debug!(
+        info!(
             &self.log,
             "Evaluating closure for parser condition, saving progress on success",
         );
@@ -308,7 +342,13 @@ impl<'r, 't> Parser<'r, 't> {
 
     #[inline]
     pub fn update(&mut self, parser: &Parser<'r, 't>) {
+        // Flags
+        self.accepts_partial = parser.accepts_partial;
+        self.in_footnote = parser.in_footnote;
+        self.has_footnote_block = parser.has_footnote_block;
         self.start_of_line = parser.start_of_line;
+
+        // Token pointers
         self.current = parser.current;
         self.remaining = parser.remaining;
     }
@@ -336,7 +376,13 @@ impl<'r, 't> Parser<'r, 't> {
                 self.remaining = remaining;
                 Ok(current)
             }
-            None => Err(self.make_warn(ParseWarningKind::EndOfInput)),
+            None => {
+                warn!(
+                    self.log,
+                    "Exhausted all tokens, yielding end of input warning",
+                );
+                Err(self.make_warn(ParseWarningKind::EndOfInput))
+            }
         }
     }
 
@@ -385,14 +431,17 @@ fn make_shared_vec<T>() -> Rc<RefCell<Vec<T>>> {
     Rc::new(RefCell::new(Vec::new()))
 }
 
+// Tests
+
 #[test]
 fn parser_newline_flag() {
     let log = &crate::build_logger();
+    let page_info = PageInfo::dummy();
 
     macro_rules! check {
         ($input:expr, $expected_steps:expr $(,)?) => {{
             let tokens = crate::tokenize(log, $input);
-            let mut parser = Parser::new(log, &tokens);
+            let mut parser = Parser::new(log, &page_info, &tokens);
             let mut actual_steps = Vec::new();
 
             // Iterate through the tokens.
