@@ -30,39 +30,43 @@ fn try_consume_fn<'p, 'r, 't>(
     log: &Logger,
     parser: &'p mut Parser<'r, 't>,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    debug!(log, "Consuming tokens until end of comment");
+    info!(log, "Consuming tokens until end of comment");
 
     check_step(parser, Token::LeftComment)?;
 
     loop {
-        let ExtractedToken { token, span, slice } = parser.current();
+        let ExtractedToken {
+            token,
+            span: _span,
+            slice: _slice,
+        } = parser.current();
 
         debug!(
             log,
             "Received token inside comment";
             "token" => token,
-            "slice" => slice,
-            "span" => SpanWrap::from(span),
+            "slice" => _slice,
+            "span" => SpanWrap::from(_span),
         );
 
         match token {
             // Hit the end of the comment, return
             Token::RightComment => {
-                trace!(log, "Reached end of comment, returning");
+                debug!(log, "Reached end of comment, returning");
                 parser.step()?;
                 return ok!(Elements::None);
             }
 
             // Hit the end of the input, abort
             Token::InputEnd => {
-                trace!(log, "Reached end of input, aborting");
+                debug!(log, "Reached end of input, aborting");
 
                 return Err(parser.make_warn(ParseWarningKind::EndOfInput));
             }
 
             // Consume any other token
             _ => {
-                trace!(log, "Token inside comment received. Discarding.");
+                debug!(log, "Token inside comment received. Discarding.");
                 parser.step()?;
             }
         }
