@@ -30,7 +30,7 @@ fn try_consume_fn<'p, 'r, 't>(
     log: &Logger,
     parser: &'p mut Parser<'r, 't>,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    debug!(log, "Consuming token as an email");
+    info!(log, "Consuming token as an email");
 
     ok!(Element::Email(cow!(parser.current().slice)))
 }
