@@ -31,7 +31,7 @@ fn try_consume_fn<'p, 'r, 't>(
     log: &Logger,
     parser: &'p mut Parser<'r, 't>,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    debug!(log, "Trying to create header container");
+    info!(log, "Trying to create header container");
 
     macro_rules! step {
         ($token:expr) => {{
