@@ -30,7 +30,7 @@ fn try_consume_fn<'p, 'r, 't>(
     log: &Logger,
     parser: &'p mut Parser<'r, 't>,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    debug!(log, "Consuming token to create a horizontal rule");
+    info!(log, "Consuming token to create a horizontal rule");
 
     check_step(parser, Token::TripleDash)?;
     parser.get_optional_line_break()?;
