@@ -20,7 +20,7 @@
 
 use super::prelude::*;
 use crate::parsing::{process_depths, DepthItem, DepthList};
-use crate::tree::{ListItem, ListType};
+use crate::tree::{AttributeMap, ListItem, ListType};
 
 const MAX_LIST_DEPTH: usize = 20;
 
@@ -43,7 +43,7 @@ fn try_consume_fn<'p, 'r, 't>(
     parser: &'p mut Parser<'r, 't>,
 ) -> ParseResult<'r, 't, Elements<'t>> {
     // We don't know the list type(s) yet, so just log that we're starting
-    debug!(log, "Parsing a list");
+    info!(log, "Parsing a list");
 
     // Context variables
     let mut depths = Vec::new();
@@ -71,7 +71,7 @@ fn try_consume_fn<'p, 'r, 't>(
 
             // Invalid token, bail
             _ => {
-                debug!(
+                warn!(
                     log,
                     "Didn't find correct bullet token or couldn't determine list depth, ending list iteration";
                     "token" => current.token,
@@ -85,7 +85,7 @@ fn try_consume_fn<'p, 'r, 't>(
 
         // Check that the depth isn't obscenely deep, to avoid DOS attacks via stack overflow.
         if depth > MAX_LIST_DEPTH {
-            info!(
+            warn!(
                 log,
                 "List item has a depth greater than the maximum! Failing";
                 "depth" => depth,
@@ -115,14 +115,14 @@ fn try_consume_fn<'p, 'r, 't>(
 
         debug!(
             log,
-            "Parsing listen item";
+            "Parsing list item";
             "list-type" => list_type.name(),
         );
 
         // For now, always expect whitespace after the bullet
         let current = parser.current();
         if current.token != Token::Whitespace {
-            debug!(
+            warn!(
                 log,
                 "Didn't find whitespace after bullet token, ending list iteration";
                 "token" => current.token,
@@ -172,10 +172,13 @@ fn build_list_element(
     list: DepthList<ListType, Vec<Element>>,
 ) -> Element {
     let build_item = |item| match item {
-        DepthItem::Item(elements) => ListItem::Elements(elements),
-        DepthItem::List(ltype, list) => {
-            ListItem::SubList(build_list_element(ltype, list))
-        }
+        DepthItem::Item(elements) => ListItem::Elements {
+            elements,
+            attributes: AttributeMap::new(),
+        },
+        DepthItem::List(ltype, list) => ListItem::SubList {
+            element: Box::new(build_list_element(ltype, list)),
+        },
     };
 
     let items = list.into_iter().map(build_item).collect();
