@@ -59,10 +59,11 @@ mod raw;
 mod strikethrough;
 mod subscript;
 mod superscript;
+mod table;
 mod text;
-mod todo;
 mod underline;
 mod url;
+mod variable;
 
 pub use self::block::{RULE_BLOCK, RULE_BLOCK_SKIP_NEWLINE, RULE_BLOCK_STAR};
 pub use self::blockquote::RULE_BLOCKQUOTE;
@@ -90,7 +91,8 @@ pub use self::raw::RULE_RAW;
 pub use self::strikethrough::RULE_STRIKETHROUGH;
 pub use self::subscript::RULE_SUBSCRIPT;
 pub use self::superscript::RULE_SUPERSCRIPT;
+pub use self::table::RULE_TABLE;
 pub use self::text::RULE_TEXT;
-pub use self::todo::RULE_TODO;
 pub use self::underline::RULE_UNDERLINE;
 pub use self::url::RULE_URL;
+pub use self::variable::RULE_VARIABLE;
