@@ -31,7 +31,7 @@ fn try_consume_fn<'p, 'r, 't>(
     log: &Logger,
     parser: &'p mut Parser<'r, 't>,
 ) -> ParseResult<'r, 't, Elements<'t>> {
-    debug!(log, "Consuming token as a URL");
+    info!(log, "Consuming token as a URL");
 
     let token = parser.current();
     let url = cow!(token.slice);
