@@ -39,3 +39,23 @@ pub fn strip_newlines(elements: &mut Vec<Element>) {
         elements.pop();
     }
 }
+
+pub fn strip_whitespace(elements: &mut Vec<Element>) {
+    // Remove leading whitespace
+    while let Some(element) = elements.first() {
+        if !element.is_whitespace() {
+            break;
+        }
+
+        elements.remove(0);
+    }
+
+    // Remove trailing whitespace
+    while let Some(element) = elements.last() {
+        if !element.is_whitespace() {
+            break;
+        }
+
+        elements.pop();
+    }
+}
