@@ -112,6 +112,9 @@ pub enum Token {
     // Tables
     //
     TableColumn,
+    TableColumnLeft,
+    TableColumnRight,
+    TableColumnCenter,
     TableColumnTitle,
 
     //
@@ -142,7 +145,7 @@ impl Token {
         log: &Logger,
         text: &'a str,
     ) -> Vec<ExtractedToken<'a>> {
-        debug!(log, "Running lexer on input");
+        info!(log, "Running lexer on input");
 
         match TokenLexer::parse(Rule::document, text) {
             Ok(pairs) => {
@@ -160,11 +163,11 @@ impl Token {
                 tokens.extend(pairs.map(|pair| Token::convert_pair(log, pair)));
                 tokens
             }
-            Err(error) => {
+            Err(_error) => {
                 // Return all of the input as one big raw text
                 // and log this as an error, since it shouldn't be happening
 
-                error!(log, "Error while lexing input in pest: {}", error);
+                crit!(log, "Error while lexing input in pest: {}", _error);
 
                 vec![ExtractedToken {
                     token: Token::Other,
@@ -253,6 +256,9 @@ impl Token {
 
             // Tables
             Rule::table_column => Token::TableColumn,
+            Rule::table_column_left => Token::TableColumnLeft,
+            Rule::table_column_right => Token::TableColumnRight,
+            Rule::table_column_center => Token::TableColumnCenter,
             Rule::table_column_title => Token::TableColumnTitle,
 
             // Text components
