@@ -25,7 +25,7 @@ use super::output::HtmlOutput;
 use crate::data::PageRef;
 use crate::next_index::{NextIndex, TableOfContentsIndex};
 use crate::render::Handle;
-use crate::tree::{Element, LinkLocation};
+use crate::tree::{Element, LinkLocation, VariableScopes};
 use crate::url::is_url;
 use crate::{info, Backlinks, PageInfo};
 use std::borrow::Cow;
@@ -44,13 +44,23 @@ where
     info: &'i PageInfo<'i>,
     handle: &'h Handle,
 
+    //
+    // Included page scopes
+    //
+    variables: VariableScopes,
+
+    //
     // Fields from syntax tree
+    //
     table_of_contents: &'e [Element<'t>],
     footnotes: &'e [Vec<Element<'t>>],
 
+    //
     // Other fields to track
+    //
     code_snippet_index: NonZeroUsize,
     table_of_contents_index: usize,
+    footnote_index: NonZeroUsize,
 }
 
 impl<'i, 'h, 'e, 't> HtmlContext<'i, 'h, 'e, 't> {
@@ -68,10 +78,12 @@ impl<'i, 'h, 'e, 't> HtmlContext<'i, 'h, 'e, 't> {
             backlinks: Backlinks::new(),
             info,
             handle,
+            variables: VariableScopes::new(),
             table_of_contents,
             footnotes,
             code_snippet_index: NonZeroUsize::new(1).unwrap(),
             table_of_contents_index: 0,
+            footnote_index: NonZeroUsize::new(1).unwrap(),
         }
     }
 
@@ -126,6 +138,16 @@ impl<'i, 'h, 'e, 't> HtmlContext<'i, 'h, 'e, 't> {
         &self.info.language
     }
 
+    #[inline]
+    pub fn variables(&self) -> &VariableScopes {
+        &self.variables
+    }
+
+    #[inline]
+    pub fn variables_mut(&mut self) -> &mut VariableScopes {
+        &mut self.variables
+    }
+
     #[inline]
     pub fn table_of_contents(&self) -> &'e [Element<'t>] {
         self.table_of_contents
@@ -148,6 +170,12 @@ impl<'i, 'h, 'e, 't> HtmlContext<'i, 'h, 'e, 't> {
         index
     }
 
+    pub fn next_footnote_index(&mut self) -> NonZeroUsize {
+        let index = self.footnote_index;
+        self.footnote_index = NonZeroUsize::new(index.get() + 1).unwrap();
+        index
+    }
+
     // Backlinks
     #[inline]
     pub fn add_link(&mut self, link: &LinkLocation) {
