@@ -29,23 +29,26 @@ pub fn render_anchor(
     attributes: &AttributeMap,
     target: Option<AnchorTarget>,
 ) {
-    debug!(
+    info!(
         log,
         "Rendering anchor";
         "elements-len" => elements.len(),
         "target" => target_str(target),
     );
 
-    let mut tag = ctx.html().a();
+    let target_value = match target {
+        Some(target) => target.html_attr(),
+        None => "",
+    };
 
-    // Set <a> attributes
-    if let Some(target) = target {
-        tag.attr("target", &[target.html_attr()]);
-    }
-    tag.attr_map(attributes);
-
-    // Add <a> internals
-    tag.inner(log, &elements);
+    ctx.html()
+        .a()
+        .attr(attr!(
+            "is" => "wj-anchor",
+            "target" => target_value; if target.is_some();;
+            attributes
+        ))
+        .inner(log, elements);
 }
 
 pub fn render_link(
@@ -55,7 +58,7 @@ pub fn render_link(
     label: &LinkLabel,
     target: Option<AnchorTarget>,
 ) {
-    debug!(
+    info!(
         log,
         "Rendering link";
         "link" => link,
@@ -68,21 +71,25 @@ pub fn render_link(
     ctx.add_link(link);
 
     let url = normalize_link(link, ctx.handle());
+    let target_value = match target {
+        Some(target) => target.html_attr(),
+        None => "",
+    };
 
-    // Create <a> and set attributes
     let mut tag = ctx.html().a();
-    tag.attr("href", &[&url]);
-
-    if let Some(target) = target {
-        tag.attr("target", &[target.html_attr()]);
-    }
+    tag.attr(attr!(
+        "is" => "wj-link",
+        "href" => &url,
+        "target" => target_value; if target.is_some(),
+    ));
 
     // Add <a> internals, i.e. the link name
     handle.get_link_label(log, link, label, |label| {
-        tag.inner(log, &label);
+        tag.inner(log, label);
     });
 }
 
+#[cfg(feature = "log")]
 fn target_str(target: Option<AnchorTarget>) -> &'static str {
     match target {
         Some(target) => target.name(),
