@@ -22,16 +22,20 @@
 
 mod collapsible;
 mod container;
+mod footnotes;
 mod iframe;
 mod image;
+mod include;
 mod input;
 mod link;
 mod list;
-mod table_of_contents;
+mod table;
 mod text;
+mod toc;
 mod user;
 
 mod prelude {
+    pub use super::super::attributes::AddedAttributes;
     pub use super::super::context::HtmlContext;
     pub use super::{render_element, render_elements};
     pub use crate::log::prelude::*;
@@ -40,15 +44,18 @@ mod prelude {
 
 use self::collapsible::{render_collapsible, Collapsible};
 use self::container::{render_color, render_container};
+use self::footnotes::{render_footnote, render_footnote_block};
 use self::iframe::{render_html, render_iframe};
 use self::image::render_image;
+use self::include::{render_include, render_variable};
 use self::input::{render_checkbox, render_radio_button};
 use self::link::{render_anchor, render_link};
 use self::list::render_list;
-use self::table_of_contents::render_table_of_contents;
+use self::table::render_table;
 use self::text::{render_code, render_email, render_wikitext_raw};
+use self::toc::render_table_of_contents;
 use self::user::render_user;
-use super::super::condition::{check_ifcategory, check_iftags};
+use super::attributes::AddedAttributes;
 use super::HtmlContext;
 use crate::log::prelude::*;
 use crate::render::ModuleRenderMode;
@@ -56,7 +63,7 @@ use crate::tree::Element;
 use ref_map::*;
 
 pub fn render_elements(log: &Logger, ctx: &mut HtmlContext, elements: &[Element]) {
-    debug!(log, "Rendering elements"; "elements-len" => elements.len());
+    info!(log, "Rendering elements"; "elements-len" => elements.len());
 
     for element in elements {
         render_element(log, ctx, element);
@@ -70,7 +77,7 @@ pub fn render_element(log: &Logger, ctx: &mut HtmlContext, element: &Element) {
         };
     }
 
-    debug!(log, "Rendering element"; "element" => element.name());
+    info!(log, "Rendering element"; "element" => element.name());
 
     match element {
         Element::Container(container) => render_container(log, ctx, container),
@@ -80,7 +87,9 @@ pub fn render_element(log: &Logger, ctx: &mut HtmlContext, element: &Element) {
         }
         Element::Text(text) => ctx.push_escaped(text),
         Element::Raw(text) => render_wikitext_raw(log, ctx, text),
+        Element::Variable(name) => render_variable(log, ctx, name),
         Element::Email(email) => render_email(log, ctx, email),
+        Element::Table(table) => render_table(log, ctx, table),
         Element::Anchor {
             elements,
             attributes,
@@ -102,7 +111,6 @@ pub fn render_element(log: &Logger, ctx: &mut HtmlContext, element: &Element) {
             items,
             attributes,
         } => render_list(log, ctx, *ltype, items, attributes),
-        Element::ListItem(_) => panic!("Reached ancillary element"),
         Element::RadioButton {
             name,
             checked,
@@ -133,25 +141,15 @@ pub fn render_element(log: &Logger, ctx: &mut HtmlContext, element: &Element) {
                 *show_bottom,
             ),
         ),
-        Element::IfCategory {
-            conditions,
-            elements,
-        } => {
-            if check_ifcategory(log, ctx.info(), conditions) {
-                render_elements(log, ctx, elements);
-            }
-        }
-        Element::IfTags {
-            conditions,
-            elements,
-        } => {
-            if check_iftags(log, ctx.info(), conditions) {
-                render_elements(log, ctx, elements);
-            }
-        }
         Element::TableOfContents { align, attributes } => {
             render_table_of_contents(log, ctx, *align, attributes)
         }
+        Element::Footnote => render_footnote(log, ctx),
+        Element::FootnoteBlock { title, hide } => {
+            if !(*hide || ctx.footnotes().is_empty()) {
+                render_footnote_block(log, ctx, ref_cow!(title));
+            }
+        }
         Element::User { name, show_avatar } => render_user(log, ctx, name, *show_avatar),
         Element::Color { color, elements } => render_color(log, ctx, color, elements),
         Element::Code { contents, language } => {
@@ -159,6 +157,12 @@ pub fn render_element(log: &Logger, ctx: &mut HtmlContext, element: &Element) {
         }
         Element::Html { contents } => render_html(log, ctx, contents),
         Element::Iframe { url, attributes } => render_iframe(log, ctx, url, attributes),
+        Element::Include {
+            variables,
+            location,
+            elements,
+            ..
+        } => render_include(log, ctx, location, variables, elements),
         Element::LineBreak => {
             ctx.html().br();
         }
@@ -170,10 +174,14 @@ pub fn render_element(log: &Logger, ctx: &mut HtmlContext, element: &Element) {
             }
         }
         Element::ClearFloat(clear_float) => {
-            ctx.html().div().attr("class", &[clear_float.html_class()]);
+            ctx.html().div().attr(attr!(
+                "is" => "wj-clear-float",
+                "class" => clear_float.html_class(),
+            ));
         }
         Element::HorizontalRule => {
             ctx.html().hr();
         }
+        Element::Partial(_) => panic!("Encountered partial element during parsing"),
     }
 }
