@@ -20,7 +20,6 @@
 
 //! Module that implements text rendering for `Element` and its children.
 
-use super::super::condition::{check_ifcategory, check_iftags};
 use super::TextContext;
 use crate::log::prelude::*;
 use crate::render::ModuleRenderMode;
@@ -29,7 +28,7 @@ use crate::url::normalize_link;
 use std::borrow::Cow;
 
 pub fn render_elements(log: &Logger, ctx: &mut TextContext, elements: &[Element]) {
-    debug!(log, "Rendering elements"; "elements-len" => elements.len());
+    info!(log, "Rendering elements"; "elements-len" => elements.len());
 
     for element in elements {
         render_element(log, ctx, element);
@@ -37,7 +36,7 @@ pub fn render_elements(log: &Logger, ctx: &mut TextContext, elements: &[Element]
 }
 
 pub fn render_element(log: &Logger, ctx: &mut TextContext, element: &Element) {
-    debug!(log, "Rendering element"; "element" => element.name());
+    info!(log, "Rendering element"; "element" => element.name());
 
     match element {
         Element::Container(container) => {
@@ -99,6 +98,45 @@ pub fn render_element(log: &Logger, ctx: &mut TextContext, element: &Element) {
         Element::Text(text) | Element::Raw(text) | Element::Email(text) => {
             ctx.push_str(text)
         }
+        Element::Variable(name) => {
+            let value = ctx.variables().get(name);
+
+            info!(
+                log,
+                "Rendering variable";
+                "name" => name.as_ref(),
+                "value" => value,
+            );
+
+            let value = match value {
+                Some(value) => str!(value),
+                None => format!("{{${}}}", name),
+            };
+
+            ctx.push_str(&value);
+        }
+        Element::Table(table) => {
+            if !ctx.ends_with_newline() {
+                ctx.add_newline();
+            }
+
+            for row in &table.rows {
+                ctx.push_str("|| ");
+
+                for (i, cell) in row.cells.iter().enumerate() {
+                    render_elements(log, ctx, &cell.elements);
+
+                    if i < row.cells.len() - 1 {
+                        ctx.push_str(" || ");
+                    }
+                }
+
+                ctx.push_str(" ||");
+                ctx.add_newline();
+            }
+
+            ctx.add_newline();
+        }
         Element::Anchor {
             elements,
             attributes,
@@ -159,7 +197,7 @@ pub fn render_element(log: &Logger, ctx: &mut TextContext, element: &Element) {
 
             for item in items {
                 match item {
-                    ListItem::Elements(elements) => {
+                    ListItem::Elements { elements, .. } => {
                         // Don't do anything if it's empty
                         if elements.is_empty() {
                             continue;
@@ -184,16 +222,15 @@ pub fn render_element(log: &Logger, ctx: &mut TextContext, element: &Element) {
                         render_elements(log, ctx, elements);
                         ctx.add_newline();
                     }
-                    ListItem::SubList(list) => {
+                    ListItem::SubList { element } => {
                         // Update bullet depth
                         ctx.incr_list_depth();
-                        render_element(log, ctx, list);
+                        render_element(log, ctx, element);
                         ctx.decr_list_depth();
                     }
                 }
             }
         }
-        Element::ListItem(_) => panic!("Reached ancillary element"),
         Element::RadioButton { checked, .. } => {
             str_write!(ctx, "({}) ", if *checked { '*' } else { ' ' })
         }
@@ -240,24 +277,8 @@ pub fn render_element(log: &Logger, ctx: &mut TextContext, element: &Element) {
                 ctx.add_newline();
             }
         }
-        Element::IfCategory {
-            conditions,
-            elements,
-        } => {
-            if check_ifcategory(log, ctx.info(), conditions) {
-                render_elements(log, ctx, elements);
-            }
-        }
-        Element::IfTags {
-            conditions,
-            elements,
-        } => {
-            if check_iftags(log, ctx.info(), conditions) {
-                render_elements(log, ctx, elements);
-            }
-        }
         Element::TableOfContents { .. } => {
-            debug!(log, "Rendering table of contents");
+            info!(log, "Rendering table of contents");
 
             let table_of_contents_title =
                 ctx.handle()
@@ -268,6 +289,45 @@ pub fn render_element(log: &Logger, ctx: &mut TextContext, element: &Element) {
             ctx.add_newline();
             render_elements(log, ctx, ctx.table_of_contents());
         }
+        Element::Footnote => {
+            info!(log, "Rendering footnote reference");
+
+            let index = ctx.next_footnote_index();
+            str_write!(ctx, "[{}]", index);
+        }
+        Element::FootnoteBlock { title, hide } => {
+            info!(log, "Rendering footnote block");
+
+            if *hide || ctx.footnotes().is_empty() {
+                return;
+            }
+
+            // Render footnote title
+            let title_default;
+            let title: &str = match title {
+                Some(title) => title.as_ref(),
+                None => {
+                    title_default = ctx.handle().get_message(
+                        log,
+                        ctx.language(),
+                        "footnote-block-title",
+                    );
+                    title_default
+                }
+            };
+
+            ctx.add_newline();
+            ctx.push_str(title);
+            ctx.add_newline();
+
+            // Render footnotes in order.
+            for (index, contents) in ctx.footnotes().iter().enumerate() {
+                str_write!(ctx, "{}. ", index + 1);
+
+                render_elements(log, ctx, contents);
+                ctx.add_newline();
+            }
+        }
         Element::User { name, .. } => ctx.push_str(name),
         Element::Color { elements, .. } => render_elements(log, ctx, elements),
         Element::Code { contents, language } => {
@@ -282,6 +342,26 @@ pub fn render_element(log: &Logger, ctx: &mut TextContext, element: &Element) {
             str_write!(ctx, "```html\n{}\n```", contents);
         }
         Element::Iframe { url, .. } => str_write!(ctx, "[iframe: {}]", url),
+        Element::Include {
+            variables,
+            elements,
+            location: _location,
+            ..
+        } => {
+            info!(
+                log,
+                "Rendering include";
+                "location" => str!(_location),
+                "variables-len" => variables.len(),
+                "elements-len" => elements.len(),
+            );
+
+            ctx.variables_mut().push_scope(variables);
+
+            render_elements(log, ctx, elements);
+
+            ctx.variables_mut().pop_scope();
+        }
         Element::LineBreak => ctx.add_newline(),
         Element::LineBreaks(amount) => {
             for _ in 0..amount.get() {
@@ -304,6 +384,7 @@ pub fn render_element(log: &Logger, ctx: &mut TextContext, element: &Element) {
             ctx.push_str("------");
             ctx.add_newline();
         }
+        Element::Partial(_) => panic!("Encountered partial element during parsing"),
     }
 }
 
