@@ -23,7 +23,7 @@
 //! Additionally performs some other tests from the parser which are better
 //! in a dedicated test file.
 
-use crate::includes::DebugIncluder;
+use super::includer::TestIncluder;
 use crate::log::prelude::*;
 use crate::parsing::ParseWarning;
 use crate::render::html::HtmlRender;
@@ -35,6 +35,7 @@ use std::borrow::Cow;
 use std::fs::{self, File};
 use std::io::Read;
 use std::path::{Path, PathBuf};
+use std::process;
 use void::ResultVoidExt;
 
 /// Temporary measure to not run certain tests.
@@ -70,6 +71,30 @@ macro_rules! file_name {
     };
 }
 
+// Debugging execution
+
+fn only_test_should_skip(name: &str) -> bool {
+    assert!(!ONLY_TESTS.is_empty());
+
+    for pattern in ONLY_TESTS.iter() {
+        // Literal test name
+        if pattern == &name {
+            return false;
+        }
+
+        // Test prefix
+        if pattern.ends_with('-') {
+            if name.starts_with(pattern) {
+                return false;
+            }
+        }
+    }
+
+    true
+}
+
+// Newline normalization
+
 #[cfg(not(target_os = "windows"))]
 fn process_newlines(_: &mut String) {}
 
@@ -81,6 +106,8 @@ fn process_newlines(text: &mut String) {
     }
 }
 
+// Test runner
+
 #[derive(Serialize, Deserialize, Debug)]
 struct Test<'a> {
     #[serde(skip)]
@@ -159,7 +186,7 @@ impl Test<'_> {
             return;
         }
 
-        if !ONLY_TESTS.is_empty() && !ONLY_TESTS.contains(&&*self.name) {
+        if !ONLY_TESTS.is_empty() && only_test_should_skip(&&*self.name) {
             println!("+ {} [SKIPPED]", self.name);
             return;
         }
@@ -185,12 +212,12 @@ impl Test<'_> {
         };
 
         let (mut text, _pages) =
-            crate::include(log, &self.input, DebugIncluder, || unreachable!())
+            crate::include(log, &self.input, TestIncluder, || unreachable!())
                 .void_unwrap();
 
         crate::preprocess(log, &mut text);
         let tokens = crate::tokenize(log, &text);
-        let result = crate::parse(log, &tokens);
+        let result = crate::parse(log, &page_info, &tokens);
         let (tree, warnings) = result.into();
         let html_output = HtmlRender.render(log, &page_info, &tree);
         let text_output = TextRender.render(log, &page_info, &tree);
@@ -330,4 +357,12 @@ fn ast_and_html() {
     for test in tests {
         test.run(&log);
     }
+
+    // Ensure we don't accidentally commit excluded tests
+    if !SKIP_TESTS.is_empty() || !ONLY_TESTS.is_empty() {
+        println!("Files are being skipped, returning failure.");
+        println!("Remember to re-enable all tests before committing!");
+
+        process::exit(2);
+    }
 }
