@@ -203,14 +203,24 @@ where
         }};
     }
 
-    let list_item = elements.prop_map(|elements| ListItem::Elements(elements));
+    let list_item = (elements, arb_attribute_map()).prop_map(|(elements, attributes)| {
+        ListItem::Elements {
+            elements,
+            attributes,
+        }
+    });
     let leaf = make_list!(proptest::collection::vec(list_item, 1..10));
 
     leaf.prop_recursive(
         5,  // Levels deep
         30, // Number of total nodes
         10, // Up to X items per collection
-        |inner| make_list!(inner.prop_map(|element| vec![ListItem::SubList(element)])),
+        |inner| {
+            make_list!(inner.prop_map(|element| {
+                let element = Box::new(element);
+                vec![ListItem::SubList { element }]
+            }))
+        },
     )
 }
 
@@ -335,7 +345,8 @@ fn arb_element_leaf() -> impl Strategy<Value = Element<'static>> {
         cow!(".*").prop_map(|contents| Element::Html { contents }),
         // TODO: Element::Iframe
         Just(Element::LineBreak),
-        (1..50u32).prop_map(|count| Element::LineBreaks(NonZeroU32::new(count).unwrap())),
+        (1..50_u32)
+            .prop_map(|count| Element::LineBreaks(NonZeroU32::new(count).unwrap())),
         select!([ClearFloat::Both, ClearFloat::Left, ClearFloat::Right])
             .prop_map(Element::ClearFloat),
         Just(Element::HorizontalRule),
