@@ -24,7 +24,6 @@ mod align;
 mod anchor;
 mod clear_float;
 mod clone;
-mod condition;
 mod container;
 mod element;
 mod heading;
@@ -32,13 +31,15 @@ mod image;
 mod link;
 mod list;
 mod module;
+mod partial;
+mod table;
 mod tag;
+mod variables;
 
 pub use self::align::*;
 pub use self::anchor::*;
 pub use self::attribute::AttributeMap;
 pub use self::clear_float::*;
-pub use self::condition::*;
 pub use self::container::*;
 pub use self::element::*;
 pub use self::heading::*;
@@ -46,7 +47,10 @@ pub use self::image::*;
 pub use self::link::*;
 pub use self::list::*;
 pub use self::module::*;
+pub use self::partial::*;
+pub use self::table::*;
 pub use self::tag::*;
+pub use self::variables::*;
 
 use self::clone::{elements_lists_to_owned, elements_to_owned, strings_to_owned};
 use crate::parsing::{ParseOutcome, ParseWarning};
