@@ -21,12 +21,10 @@
 #[macro_use]
 mod macros;
 
-#[cfg(feature = "css")]
-mod css;
-
 mod error;
 mod log;
 mod misc;
+mod page_info;
 mod parsing;
 mod preproc;
 mod render;
